# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.insecureHashlibNew

Module implementing a check for use of insecure md4, md5, or sha1 hash functions in hashlib.new().

### Global Attributes

None

### Classes

None

### Functions

_hashlibFunc | Function to check for use of insecure md4, md5, sha or sha1 hash functions in hashlib.new() if 'usedforsecurity' is not set to 'False'.
_hashlibNew | Function to check for use of insecure md4, md5, sha or sha1 hash functions in hashlib.new().
checkHashlib | Function to check for use of insecure md4, md5, sha or sha1 hash functions in hashlib.new().
getChecks | Public method to get a dictionary with checks handled by this module.

## _hashlibFunc

_hashlibFunc(reportError, context, config)

Function to check for use of insecure md4, md5, sha or sha1 hash functions in hashlib.new() if 'usedforsecurity' is not set to 'False'.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## _hashlibNew

_hashlibNew(reportError, context, config)

Function to check for use of insecure md4, md5, sha or sha1 hash functions in hashlib.new().

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## checkHashlib

checkHashlib(reportError, context, config)

Function to check for use of insecure md4, md5, sha or sha1 hash functions in hashlib.new().

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up